{% load social_widgets %}
{% block widget %}
{% endblock widget %}
{% block javascript %}
{% if nojs or widget_service in social_widgets_javascript %}
   {# Do not load JavaScript then #}
{% else %}
<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");</script>{% endif %}
{% endblock javascript %}
